GetThingConnectivityDataOutput

Struct GetThingConnectivityDataOutput 

#[non_exhaustive]
pub struct GetThingConnectivityDataOutput {
Show 13 fields pub thing_name: Option<String>, pub connected: Option<bool>, pub timestamp: Option<DateTime>, pub disconnect_reason: Option<DisconnectReasonValue>, pub source_ip: Option<String>, pub source_port: Option<i32>, pub target_ip: Option<String>, pub target_port: Option<i32>, pub vpc_endpoint_id: Option<String>, pub keep_alive_duration: Option<i32>, pub clean_session: Option<bool>, pub session_expiry: Option<i64>, pub client_id: Option<String>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
thing_name: Option<String>

The name of your IoT thing.

connected: Option<bool>

A Boolean that indicates the connectivity status.

timestamp: Option<DateTime>

The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.

disconnect_reason: Option<DisconnectReasonValue>

The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be UNKNOWN for devices that have never connected or have been disconnected for more than an hour.

source_ip: Option<String>

The IP address of the client that initiated the connection.

source_port: Option<i32>

The client's source port.

target_ip: Option<String>

The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.

target_port: Option<i32>

The port number of the Amazon Web Services IoT Core endpoint that the client connected to.

vpc_endpoint_id: Option<String>

The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.

keep_alive_duration: Option<i32>

The keep-alive interval in seconds that the client specified when establishing the connection.

clean_session: Option<bool>

Indicates whether the client is using a clean session. Returns true for clean sessions.

session_expiry: Option<i64>

The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.

client_id: Option<String>

The unique identifier of the MQTT client.

Implementations

Source

impl GetThingConnectivityDataOutput

pub fn thing_name(&self) -> Option<&str>

The name of your IoT thing.

pub fn connected(&self) -> Option<bool>

A Boolean that indicates the connectivity status.

pub fn timestamp(&self) -> Option<&DateTime>

The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.

pub fn disconnect_reason(&self) -> Option<&DisconnectReasonValue>

The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be UNKNOWN for devices that have never connected or have been disconnected for more than an hour.

pub fn source_ip(&self) -> Option<&str>

The IP address of the client that initiated the connection.

pub fn source_port(&self) -> Option<i32>

The client's source port.

pub fn target_ip(&self) -> Option<&str>

The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.

pub fn target_port(&self) -> Option<i32>

The port number of the Amazon Web Services IoT Core endpoint that the client connected to.

pub fn vpc_endpoint_id(&self) -> Option<&str>

The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.

pub fn keep_alive_duration(&self) -> Option<i32>

The keep-alive interval in seconds that the client specified when establishing the connection.

pub fn clean_session(&self) -> Option<bool>

Indicates whether the client is using a clean session. Returns true for clean sessions.

pub fn session_expiry(&self) -> Option<i64>

The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.

pub fn client_id(&self) -> Option<&str>

The unique identifier of the MQTT client.

Source

impl GetThingConnectivityDataOutput

pub fn builder() -> GetThingConnectivityDataOutputBuilder

Creates a new builder-style object to manufacture GetThingConnectivityDataOutput.