#[non_exhaustive]pub struct InfluxDbDestinationProperties {
pub endpoint: Option<String>,
pub influx_db_version: Option<InfluxDbVersion>,
pub secret_id: Option<String>,
pub secret_type: Option<InfluxDbSecretType>,
pub secret_key: Option<String>,
}Expand description
The properties of an existing InfluxDB topic rule destination, as returned by CreateTopicRuleDestination and GetTopicRuleDestination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: Option<String>The URL of the InfluxDB instance that the destination writes to.
influx_db_version: Option<InfluxDbVersion>The major version of the InfluxDB instance. Valid values are V2 and V3.
secret_id: Option<String>The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
secret_type: Option<InfluxDbSecretType>The type of the secret that contains the InfluxDB API token. Valid values are SecretString and SecretBinary.
secret_key: Option<String>The key that is read from the secret value when the secret contains a JSON object.
Implementations
Sourceimpl InfluxDbDestinationProperties
impl InfluxDbDestinationProperties
Sourcepub fn endpoint(&self) -> Option<&str>
pub fn endpoint(&self) -> Option<&str>
The URL of the InfluxDB instance that the destination writes to.
Sourcepub fn influx_db_version(&self) -> Option<&InfluxDbVersion>
pub fn influx_db_version(&self) -> Option<&InfluxDbVersion>
The major version of the InfluxDB instance. Valid values are V2 and V3.
Sourcepub fn secret_id(&self) -> Option<&str>
pub fn secret_id(&self) -> Option<&str>
The ARN or name of the Amazon Web Services Secrets Manager secret that contains the InfluxDB API token.
Sourcepub fn secret_type(&self) -> Option<&InfluxDbSecretType>
pub fn secret_type(&self) -> Option<&InfluxDbSecretType>
The type of the secret that contains the InfluxDB API token. Valid values are SecretString and SecretBinary.
Sourcepub fn secret_key(&self) -> Option<&str>
pub fn secret_key(&self) -> Option<&str>
The key that is read from the secret value when the secret contains a JSON object.
Sourceimpl InfluxDbDestinationProperties
impl InfluxDbDestinationProperties
Sourcepub fn builder() -> InfluxDbDestinationPropertiesBuilder
pub fn builder() -> InfluxDbDestinationPropertiesBuilder
Creates a new builder-style object to manufacture InfluxDbDestinationProperties.