#[non_exhaustive]pub struct LogEventConfiguration {
pub event_type: String,
pub log_level: Option<LogLevel>,
pub log_destination: Option<String>,
}Expand description
Configuration for event-based logging that specifies which event types to log and their logging settings. Used for account-level logging overrides.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_type: StringThe type of event to log. These include event types like Connect, Publish, and Disconnect.
log_level: Option<LogLevel>The logging level for the specified event type. Determines the verbosity of log messages generated for this event type.
log_destination: Option<String>CloudWatch Log Group for event-based logging. Specifies where log events should be sent. The log destination for event-based logging overrides default Log Group for the specified event type and applies to all resources associated with that event.
Implementations
Sourceimpl LogEventConfiguration
impl LogEventConfiguration
Sourcepub fn event_type(&self) -> &str
pub fn event_type(&self) -> &str
The type of event to log. These include event types like Connect, Publish, and Disconnect.
Sourcepub fn log_level(&self) -> Option<&LogLevel>
pub fn log_level(&self) -> Option<&LogLevel>
The logging level for the specified event type. Determines the verbosity of log messages generated for this event type.
Sourcepub fn log_destination(&self) -> Option<&str>
pub fn log_destination(&self) -> Option<&str>
CloudWatch Log Group for event-based logging. Specifies where log events should be sent. The log destination for event-based logging overrides default Log Group for the specified event type and applies to all resources associated with that event.
Sourceimpl LogEventConfiguration
impl LogEventConfiguration
Sourcepub fn builder() -> LogEventConfigurationBuilder
pub fn builder() -> LogEventConfigurationBuilder
Creates a new builder-style object to manufacture LogEventConfiguration.