#[non_exhaustive]pub struct GetThingConnectivityDataOutput {Show 13 fields
pub thing_name: Option<String>,
pub connected: Option<bool>,
pub timestamp: Option<DateTime>,
pub disconnect_reason: Option<DisconnectReasonValue>,
pub source_ip: Option<String>,
pub source_port: Option<i32>,
pub target_ip: Option<String>,
pub target_port: Option<i32>,
pub vpc_endpoint_id: Option<String>,
pub keep_alive_duration: Option<i32>,
pub clean_session: Option<bool>,
pub session_expiry: Option<i64>,
pub client_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.thing_name: Option<String>The name of your IoT thing.
connected: Option<bool>A Boolean that indicates the connectivity status.
timestamp: Option<DateTime>The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.
disconnect_reason: Option<DisconnectReasonValue>The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be UNKNOWN for devices that have never connected or have been disconnected for more than an hour.
source_ip: Option<String>The IP address of the client that initiated the connection.
source_port: Option<i32>The client's source port.
target_ip: Option<String>The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.
target_port: Option<i32>The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
vpc_endpoint_id: Option<String>The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.
keep_alive_duration: Option<i32>The keep-alive interval in seconds that the client specified when establishing the connection.
clean_session: Option<bool>Indicates whether the client is using a clean session. Returns true for clean sessions.
session_expiry: Option<i64>The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.
client_id: Option<String>The unique identifier of the MQTT client.
Implementations
Sourceimpl GetThingConnectivityDataOutput
impl GetThingConnectivityDataOutput
Sourcepub fn thing_name(&self) -> Option<&str>
pub fn thing_name(&self) -> Option<&str>
The name of your IoT thing.
Sourcepub fn timestamp(&self) -> Option<&DateTime>
pub fn timestamp(&self) -> Option<&DateTime>
The timestamp of when the event occurred. When you enable or update the indexing configuration, this value might be the Unix epoch time (0) for devices that have never connected or have been disconnected for more than an hour.
Sourcepub fn disconnect_reason(&self) -> Option<&DisconnectReasonValue>
pub fn disconnect_reason(&self) -> Option<&DisconnectReasonValue>
The reason why the client is disconnecting. When you enable or update the indexing configuration, this value might be UNKNOWN for devices that have never connected or have been disconnected for more than an hour.
Sourcepub fn source_ip(&self) -> Option<&str>
pub fn source_ip(&self) -> Option<&str>
The IP address of the client that initiated the connection.
Sourcepub fn source_port(&self) -> Option<i32>
pub fn source_port(&self) -> Option<i32>
The client's source port.
Sourcepub fn target_ip(&self) -> Option<&str>
pub fn target_ip(&self) -> Option<&str>
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn target_port(&self) -> Option<i32>
pub fn target_port(&self) -> Option<i32>
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn vpc_endpoint_id(&self) -> Option<&str>
pub fn vpc_endpoint_id(&self) -> Option<&str>
The ID of the VPC endpoint. Present for clients connected to Amazon Web Services IoT Core via a VPC endpoint.
Sourcepub fn keep_alive_duration(&self) -> Option<i32>
pub fn keep_alive_duration(&self) -> Option<i32>
The keep-alive interval in seconds that the client specified when establishing the connection.
Sourcepub fn clean_session(&self) -> Option<bool>
pub fn clean_session(&self) -> Option<bool>
Indicates whether the client is using a clean session. Returns true for clean sessions.
Sourcepub fn session_expiry(&self) -> Option<i64>
pub fn session_expiry(&self) -> Option<i64>
The session expiry interval in seconds for the MQTT client connection. This value indicates how long the session will remain active after the client disconnects.
Sourceimpl GetThingConnectivityDataOutput
impl GetThingConnectivityDataOutput
Sourcepub fn builder() -> GetThingConnectivityDataOutputBuilder
pub fn builder() -> GetThingConnectivityDataOutputBuilder
Creates a new builder-style object to manufacture GetThingConnectivityDataOutput.